@@ -17,6 +17,8 @@ enum event_loop_job {
     UV_EVENT_DBENGINE_EXTENT_PAGE_LOOKUP,
     UV_EVENT_DBENGINE_EXTENT_PAGE_POPULATION,
     UV_EVENT_DBENGINE_EXTENT_PAGE_ALLOCATION,
+    // Metrics calculation
+    UV_EVENT_WEIGHTS_CALCULATION,
 
     // flushing related
     UV_EVENT_DBENGINE_FLUSH_MAIN_CACHE,
@@ -40,6 +42,7 @@ enum event_loop_job {
     UV_EVENT_DBENGINE_BUFFERS_CLEANUP,
     UV_EVENT_DBENGINE_FLUSH_DIRTY,
     UV_EVENT_DBENGINE_QUIESCE,
+    UV_EVENT_DBENGINE_MRG_LOAD,
     UV_EVENT_DBENGINE_SHUTDOWN,
 
     // metadata
